@@ -41,6 +41,8 @@ class MigrationCommand(BaseCommand):
                     help='Migrate all objects including news'),
             make_option('-o', '--no-interactive', action='store_true', default=False, dest='no_interactive',
                     help='Tells Django to NOT prompt the user for input of any kind.'),
+            make_option('-r', '--register-only-with-errors', action='store_true', default=False, dest='register_only_with_errors',
+                    help='Only register migrations with errors'),
     )
 
     def _log(self, msg, verbosity):
@@ -91,6 +93,7 @@ class MigrationCommand(BaseCommand):
         self.only_new_objects = options.get('only_new_objects')
         self.all_objects = options.get('all_objects')
         self.no_interactive = options.get('no_interactive')
+        self.register_only_with_errors = options.get('register_only_with_errors')
         if options.get('from_date'):
             self.from_date = datetime(*time.strptime(options.get('from_date'), '%Y-%m-%d')[:3])
         else:
@@ -221,9 +224,12 @@ class MigrationCommand(BaseCommand):
         """
         Unmark object with a "is migrating" flag.
         """
-        migration_mark.is_migrating = False
-        migration_mark.migration_fields_used = pprint.pformat(migration_fields)
-        migration_mark.save()
+        if migration_mark.has_errors or not self.register_only_with_errors:
+            migration_mark.is_migrating = False
+            migration_mark.migration_fields_used = pprint.pformat(migration_fields)
+            migration_mark.save()
+        else:
+            migration_mark.delete()
 
     def get_migration_command(self):
         return self.__class__.__module__
